/***********************************************************************
 *                copyright 2001, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/

/* define the C entry point names */

#define argstr argstr_c
#define argi4 argi4_c
#define argi8 argi8_c
#define argr4 argr4_c
#define argr8 argr8_c
#define argis argis_c
#define findarg findarg_c

#define C_ARGSTR argstr_c
#define C_ARGI4 argi4_c
#define C_ARGI8 argi8_c
#define C_ARGR4 argr4_c
#define C_ARGR8 argr8_c
#define C_ARGIS argis_c
#define C_FINDARG findarg_c

#ifndef _ArgSys_h
#include <argsys.h>
#endif
